@@ -20,47 +20,15 @@ import sys
 
 
 from ucitests import (
+    assertions,
     filters,
     fixtures,
     loaders,
+    matchers,
     tests,
 )
 
 
-class TestNameMatcher(unittest.TestCase):
-
-    def test_defaults(self):
-        nm = loaders.NameMatcher()
-        self.assertFalse(nm.matches(''))
-        self.assertFalse(nm.matches('foo'))
-
-    def test_simple_include(self):
-        nm = loaders.NameMatcher(includes=['foo'])
-        self.assertTrue(nm.matches('foo'))
-        self.assertTrue(nm.matches('XXXfooXXX'))
-
-    def test_multiple_includes(self):
-        nm = loaders.NameMatcher(includes=['foo', '^bar'])
-        self.assertTrue(nm.matches('foo'))
-        self.assertTrue(nm.matches('bar'))
-        self.assertTrue(nm.matches('barfoo'))
-        self.assertTrue(nm.matches('foobar'))
-        self.assertFalse(nm.matches('bazbar'))
-
-    def test_simple_excludes(self):
-        nm = loaders.NameMatcher(includes=['.*'], excludes=['foo'])
-        self.assertTrue(nm.matches('bar'))
-        self.assertFalse(nm.matches('foo'))
-        self.assertFalse(nm.matches('foobar'))
-
-    def test_multiple_excludes(self):
-        nm = loaders.NameMatcher(includes=['.*'], excludes=['foo$', '^bar'])
-        self.assertTrue(nm.matches('baz'))
-        self.assertTrue(nm.matches('footix'))
-        self.assertFalse(nm.matches('foo'))
-        self.assertFalse(nm.matches('barista'))
-
-
 class TestImportFromPath(unittest.TestCase):
 
     def setUp(self):
@@ -83,7 +51,16 @@ class TestImportFromPath(unittest.TestCase):
             f.write('')
         with self.assertRaises(ImportError) as cm:
             self.loader.importFromPath(d)
-        self.assertEqual('No module named foo.bar.baz', cm.exception.message)
+        assertions.assertMultiLineAlmostEqual(self, '''\
+Failed to import foo.bar.baz at ./foo.bar/baz:
+Traceback (most recent call last):
+  File "...", line ..., in importFromPath
+    return importlib.import_module(mod_name)
+  File "...", line ..., in import_module
+    __import__(name)
+ImportError: No module named foo.bar.baz
+''',
+                                              cm.exception.message)
 
     def test_invalid_python_file(self):
         with open('foo.py', 'w') as f:
@@ -96,12 +73,30 @@ class TestImportFromPath(unittest.TestCase):
             f.write("I'm no python code and I'm not even pretending")
         with self.assertRaises(ImportError) as cm:
             self.loader.importFromPath('./foo')
-        self.assertEqual("No module named foo", cm.exception.message)
+        assertions.assertMultiLineAlmostEqual(self, '''\
+Failed to import foo at ./foo:
+Traceback (most recent call last):
+  File "...", line ..., in importFromPath
+    return importlib.import_module(mod_name)
+  File "...", line ..., in import_module
+    __import__(name)
+ImportError: No module named foo
+''',
+                                              cm.exception.message)
 
     def test_unknown_file(self):
         with self.assertRaises(ImportError) as cm:
             self.loader.importFromPath('./foo.py')
-        self.assertEqual("No module named foo", cm.exception.message)
+        assertions.assertMultiLineAlmostEqual(self, '''\
+Failed to import foo at ./foo.py:
+Traceback (most recent call last):
+  File "...", line ..., in importFromPath
+    return importlib.import_module(mod_name)
+  File "...", line ..., in import_module
+    __import__(name)
+ImportError: No module named foo
+''',
+                                              cm.exception.message)
 
     def test_valid_file(self):
         self.assertIs(None, sys.modules.get('foo', None))
@@ -400,8 +395,8 @@ class T(unittest.TestCase):
         if dir_matching is None:
             dir_matching = dict(includes=['.*'])
         loader = self.loader.SubLoader(
-            dir_matcher=loaders.NameMatcher(**dir_matching),
-            file_matcher=loaders.NameMatcher(**file_matching))
+            dir_matcher=matchers.NameMatcher(**dir_matching),
+            file_matcher=matchers.NameMatcher(**file_matching))
         actual = loader.loadTestsFromFiles('.', os.listdir('.'))
         assertTestIDs(self, expected, actual)
 
@@ -680,10 +675,10 @@ class T(unittest.TestCase):
         tests.write_tree_from_desc('''
 file: t/__init__.py
 import os
-from ucitests import loaders
+from ucitests import loaders, matchers
 def load_tests(loader, std_tests, pattern):
     subloader = loader.SubLoader(
-        file_matcher=loaders.NameMatcher(includes=[r'^t\.py$']))
+        file_matcher=matchers.NameMatcher(includes=[r'^t\.py$']))
     return subloader.loadTestsFromFiles('t', os.listdir('t'))
 file: t/t.py
 import unittest
@@ -698,10 +693,10 @@ class T(unittest.TestCase):
         tests.write_tree_from_desc('''
 file: t/__init__.py
 import os
-from ucitests import loaders
+from ucitests import loaders, matchers
 def load_tests(loader, std_tests, pattern):
     subloader = loader.SubLoader(
-        dir_matcher=loaders.NameMatcher(includes=[r'^t1$']))
+        dir_matcher=matchers.NameMatcher(includes=[r'^t1$']))
     return subloader.loadTestsFromFiles('t', os.listdir('t'))
 dir: t/t1
 file: t/t1/__init__.py
